==> aslsocial-0.2.0-20130320.153522-15.jar: org/gcube/applicationsupportlayer/social/SocialPortalBridge.java <==
package org.gcube.applicationsupportlayer.social;

import java.util.List;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.applicationsupportlayer.social.ex.ApplicationProfileNotFoundException;
import org.gcube.common.core.contexts.GHNContext;
import org.gcube.common.core.informationsystem.client.ISClient;
import org.gcube.common.core.informationsystem.client.XMLResult;
import org.gcube.common.core.informationsystem.client.queries.GCUBEGenericQuery;
import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.common.core.utils.logging.GCUBEClientLog;
import org.gcube.portal.databook.server.DBCassandraAstyanaxImpl;
import org.gcube.portal.databook.server.DatabookStore;
import org.gcube.portal.databook.shared.ApplicationProfile;
import org.gcube.vomanagement.usermanagement.GroupManager;
import org.gcube.vomanagement.usermanagement.impl.liferay.LiferayGroupManager;
/**
 * 
 * @author Massimiliano Assante, ISTI-CNR
 * @version 0.1 Dec 2012
 *
 * superclass for notifications, posting news and so on
 */
public class SocialPortalBridge {

	protected static GCUBEClientLog _log = new GCUBEClientLog(SocialPortalBridge.class);
	protected ASLSession aslSession;
	protected ApplicationProfile applicationProfile;
	//unique instance
	private static DatabookStore store;
	

	/**
	 * 
	 * @param session
	 */
	public SocialPortalBridge(ASLSession session, String portletClassName) { 
		this.aslSession = session;
		this.applicationProfile = getProfileFromInfrastrucure(portletClassName);
	}
	/**
	 * 
	 * @param session
	 */
	public SocialPortalBridge(ASLSession session) { 
		this.aslSession = session;
		this.applicationProfile = null;
	}
	/**
	 * 
	 * @return the unique instance of the store
	 */
	public static synchronized DatabookStore getStoreInstance() {
		if (store == null) {
			store = new DBCassandraAstyanaxImpl();
		}
		return store;
	}

	protected String getScopeByOrganizationId(String vreid) {
		GroupManager gm = new LiferayGroupManager();
		try {
			return gm.getScope(vreid);
		} catch (Exception e) {
			_log.error("Could not find a scope for this VREid: " + vreid);
			return null;
		} 
	}
	/**
	 * Escape an html string. Escaping data received from the client helps to
	 * prevent cross-site script vulnerabilities.
	 * 
	 * @param html the html string to escape
	 * @return the escaped string
	 */
	protected String escapeHtml(String html) {
		if (html == null) {
			return null;
		}
		return html.replaceAll("&", "&amp;").replaceAll("<", "&lt;")
				.replaceAll(">", "&gt;");
	}
	/**
	 * @return the applicationProfile profile among the ones available in the infrastructure
	 */
	public ApplicationProfile getApplicationProfile() {
		return applicationProfile;
	}
	/**
	 * this method looks up the applicationProfile profile among the ones available in the infrastructure
	 * @param portletClassName your servlet class name will be used ad unique identifier for your applicationProfile
	 * @return the applicationProfile profile
	 */
	private ApplicationProfile getProfileFromInfrastrucure(String portletClassName) {
		try {
			ApplicationProfile toReturn = new ApplicationProfile();
			ISClient client = GHNContext.getImplementation(ISClient.class);
			GCUBEGenericQuery query = client.getQuery(GCUBEGenericQuery.class);


			query.setExpression("for $profile in collection('/db/Profiles/GenericResource')//Resource " +
					"where $profile/Profile/SecondaryType/string() eq 'ApplicationProfile' and  $profile/Profile/Body/AppId/string() " +
					" eq '" + portletClassName + "'" +
					"return $profile");

			GCUBEScope scope =  aslSession.getScope();

			List<XMLResult> appProfile = client.execute(query, scope.getInfrastructure());
			if (appProfile == null || appProfile.size() == 0) 
				throw new ApplicationProfileNotFoundException("Your applicationProfile is not registered in the infrastructure");
			else {
				XMLResult node = appProfile.get(0);
				List<String> currValue = null;
				currValue = node.evaluate("/Resource/Profile/Name/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setName(currValue.get(0));
				} 
				else throw new ApplicationProfileNotFoundException("Your applicationProfile NAME was not found in the profile");

				currValue = node.evaluate("/Resource/Profile/Description/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setDescription(currValue.get(0));
				} 
				else _log.warn("No Description exists for " + toReturn.getName());

				currValue = node.evaluate("/Resource/Profile/Body/AppId/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setKey(currValue.get(0));
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile ID n was not found in the profile, consider adding <AppId> element in <Body>");

				currValue = node.evaluate("/Resource/Profile/Body/ThumbnailURL/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setImageUrl(currValue.get(0));
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile Image Url was not found in the profile, consider adding <ThumbnailURL> element in <Body>");
				currValue = node.evaluate("/Resource/Profile/Body/EndPoint/Scope/text()");
				if (currValue != null && currValue.size() > 0) {
					List<String> scopes = currValue;
					boolean foundUrl = false;
					for (int i = 0; i < scopes.size(); i++) {
						if (currValue.get(i).trim().compareTo(scope.toString()) == 0) {								
							toReturn.setUrl(node.evaluate("/Resource/Profile/Body/EndPoint/URL/text()").get(i));
							toReturn.setScope(scope.toString());
							foundUrl = true;
							break;
						}						
					}
					if (! foundUrl)
						throw new ApplicationProfileNotFoundException("Your applicationProfile URL was not found in the profile for Scope: " + scope.toString());
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile EndPoint was not found in the profile, consider adding <EndPoint><Scope> element in <Body>");
				return toReturn;
			}

		} catch (Exception e) {
			_log.error("Error while trying to fetch applicationProfile profile from the infrastructure");
			e.printStackTrace();
			return null;
		} 

	}
}

==> aslsocial-0.5.0-20130712.152912-4.jar: org/gcube/applicationsupportlayer/social/SocialPortalBridge.java <==
package org.gcube.applicationsupportlayer.social;

import java.util.List;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.applicationsupportlayer.social.ex.ApplicationProfileNotFoundException;
import org.gcube.common.core.contexts.GHNContext;
import org.gcube.common.core.informationsystem.client.ISClient;
import org.gcube.common.core.informationsystem.client.XMLResult;
import org.gcube.common.core.informationsystem.client.queries.GCUBEGenericQuery;
import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.common.core.utils.logging.GCUBEClientLog;
import org.gcube.portal.databook.server.DBCassandraAstyanaxImpl;
import org.gcube.portal.databook.server.DatabookStore;
import org.gcube.portal.databook.shared.ApplicationProfile;
import org.gcube.vomanagement.usermanagement.GroupManager;
import org.gcube.vomanagement.usermanagement.impl.liferay.LiferayGroupManager;
/**
 * 
 * @author Massimiliano Assante, ISTI-CNR
 * @version 0.1 Dec 2012
 *
 * superclass for notifications, posting news and so on
 */
public class SocialPortalBridge {

	protected static GCUBEClientLog _log = new GCUBEClientLog(SocialPortalBridge.class);
	protected ASLSession aslSession;
	protected ApplicationProfile applicationProfile;
	//unique instance
	private static DatabookStore store;
	

	/**
	 * 
	 * @param session
	 */
	public SocialPortalBridge(ASLSession session, String portletClassName) { 
		this.aslSession = session;
		this.applicationProfile = getProfileFromInfrastrucure(portletClassName);
	}
	/**
	 * 
	 * @param session
	 */
	public SocialPortalBridge(ASLSession session) { 
		this.aslSession = session;
		this.applicationProfile = null;
	}
	/**
	 * 
	 * @return the unique instance of the store
	 */
	public static synchronized DatabookStore getStoreInstance() {
		if (store == null) {
			store = new DBCassandraAstyanaxImpl();
		}
		return store;
	}

	protected String getScopeByOrganizationId(String vreid) {
		GroupManager gm = new LiferayGroupManager();
		try {
			return gm.getScope(vreid);
		} catch (Exception e) {
			_log.error("Could not find a scope for this VREid: " + vreid);
			return null;
		} 
	}
	/**
	 * Escape an html string. Escaping data received from the client helps to
	 * prevent cross-site script vulnerabilities.
	 * 
	 * @param html the html string to escape
	 * @return the escaped string
	 */
	protected String escapeHtml(String html) {
		if (html == null) {
			return null;
		}
		return html.replaceAll("&", "&amp;").replaceAll("<", "&lt;")
				.replaceAll(">", "&gt;");
	}
	/**
	 * @return the applicationProfile profile among the ones available in the infrastructure
	 */
	public ApplicationProfile getApplicationProfile() {
		return applicationProfile;
	}
	/**
	 * this method looks up the applicationProfile profile among the ones available in the infrastructure
	 * @param portletClassName your servlet class name will be used ad unique identifier for your applicationProfile
	 * @return the applicationProfile profile
	 */
	private ApplicationProfile getProfileFromInfrastrucure(String portletClassName) {
		GCUBEScope scope =  aslSession.getScope();
		_log.debug("Trying to fetch applicationProfile profile from the infrastructure for " + portletClassName + " scope: " +  scope);
		try {
			ApplicationProfile toReturn = new ApplicationProfile();
			ISClient client = GHNContext.getImplementation(ISClient.class);
			GCUBEGenericQuery query = client.getQuery(GCUBEGenericQuery.class);


			query.setExpression("for $profile in collection('/db/Profiles/GenericResource')//Resource " +
					"where $profile/Profile/SecondaryType/string() eq 'ApplicationProfile' and  $profile/Profile/Body/AppId/string() " +
					" eq '" + portletClassName + "'" +
					"return $profile");

			

			List<XMLResult> appProfile = client.execute(query, scope.getInfrastructure());
			if (appProfile == null || appProfile.size() == 0) 
				throw new ApplicationProfileNotFoundException("Your applicationProfile is not registered in the infrastructure");
			else {
				XMLResult node = appProfile.get(0);
				List<String> currValue = null;
				currValue = node.evaluate("/Resource/Profile/Name/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setName(currValue.get(0));
				} 
				else throw new ApplicationProfileNotFoundException("Your applicationProfile NAME was not found in the profile");

				currValue = node.evaluate("/Resource/Profile/Description/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setDescription(currValue.get(0));
				} 
				else _log.warn("No Description exists for " + toReturn.getName());

				currValue = node.evaluate("/Resource/Profile/Body/AppId/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setKey(currValue.get(0));
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile ID n was not found in the profile, consider adding <AppId> element in <Body>");

				currValue = node.evaluate("/Resource/Profile/Body/ThumbnailURL/text()");
				if (currValue != null && currValue.size() > 0) {
					toReturn.setImageUrl(currValue.get(0));
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile Image Url was not found in the profile, consider adding <ThumbnailURL> element in <Body>");
				currValue = node.evaluate("/Resource/Profile/Body/EndPoint/Scope/text()");
				if (currValue != null && currValue.size() > 0) {
					List<String> scopes = currValue;
					boolean foundUrl = false;
					for (int i = 0; i < scopes.size(); i++) {
						if (currValue.get(i).trim().compareTo(scope.toString()) == 0) {								
							toReturn.setUrl(node.evaluate("/Resource/Profile/Body/EndPoint/URL/text()").get(i));
							toReturn.setScope(scope.toString());
							foundUrl = true;
							break;
						}						
					}
					if (! foundUrl)
						throw new ApplicationProfileNotFoundException("Your applicationProfile URL was not found in the profile for Scope: " + scope.toString());
				}
				else throw new ApplicationProfileNotFoundException("Your applicationProfile EndPoint was not found in the profile, consider adding <EndPoint><Scope> element in <Body>");
				_log.debug("Returning " + toReturn);
				return toReturn;
			}

		} catch (Exception e) {
			_log.error("Error while trying to fetch applicationProfile profile from the infrastructure");
			e.printStackTrace();
			return null;
		} 

	}
}
